@@ -120,7 +120,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -136,34 +136,34 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudwatch
-import aws_cdk.aws_iam
-import aws_cdk.aws_kinesis
-import aws_cdk.aws_kinesisfirehose
-import aws_cdk.aws_logs
-import aws_cdk.aws_s3
-import constructs
+import aws_cdk.aws_cloudwatch as _aws_cdk_aws_cloudwatch_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_kinesis as _aws_cdk_aws_kinesis_ceddda9d
+import aws_cdk.aws_kinesisfirehose as _aws_cdk_aws_kinesisfirehose_ceddda9d
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class KinesisStreamsToKinesisFirehoseToS3(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-kinesisstreams-kinesisfirehose-s3.KinesisStreamsToKinesisFirehoseToS3",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+        existing_logging_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+        existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        kinesis_stream_props: typing.Optional[typing.Union[_aws_cdk_aws_kinesis_ceddda9d.StreamProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -185,23 +185,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
         :summary: Constructs a new instance of the KinesisStreamsToKinesisFirehoseToS3 class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_firehose_props: typing.Any = None,
-                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8841925e06edd471b185af1ee7071d8da371a758c42ca2bf6eb79c9815681857)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KinesisStreamsToKinesisFirehoseToS3Props(
@@ -221,50 +205,52 @@ class KinesisStreamsToKinesisFirehoseToS3(
 
     @builtins.property
     @jsii.member(jsii_name="kinesisFirehose")
-    def kinesis_firehose(self) -> aws_cdk.aws_kinesisfirehose.CfnDeliveryStream:
-        return typing.cast(aws_cdk.aws_kinesisfirehose.CfnDeliveryStream, jsii.get(self, "kinesisFirehose"))
+    def kinesis_firehose(
+        self,
+    ) -> _aws_cdk_aws_kinesisfirehose_ceddda9d.CfnDeliveryStream:
+        return typing.cast(_aws_cdk_aws_kinesisfirehose_ceddda9d.CfnDeliveryStream, jsii.get(self, "kinesisFirehose"))
 
     @builtins.property
     @jsii.member(jsii_name="kinesisFirehoseLogGroup")
-    def kinesis_firehose_log_group(self) -> aws_cdk.aws_logs.LogGroup:
-        return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "kinesisFirehoseLogGroup"))
+    def kinesis_firehose_log_group(self) -> _aws_cdk_aws_logs_ceddda9d.LogGroup:
+        return typing.cast(_aws_cdk_aws_logs_ceddda9d.LogGroup, jsii.get(self, "kinesisFirehoseLogGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="kinesisFirehoseRole")
-    def kinesis_firehose_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisFirehoseRole"))
+    def kinesis_firehose_role(self) -> _aws_cdk_aws_iam_ceddda9d.Role:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.get(self, "kinesisFirehoseRole"))
 
     @builtins.property
     @jsii.member(jsii_name="kinesisStream")
-    def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
-        return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
+    def kinesis_stream(self) -> _aws_cdk_aws_kinesis_ceddda9d.Stream:
+        return typing.cast(_aws_cdk_aws_kinesis_ceddda9d.Stream, jsii.get(self, "kinesisStream"))
 
     @builtins.property
     @jsii.member(jsii_name="kinesisStreamRole")
-    def kinesis_stream_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisStreamRole"))
+    def kinesis_stream_role(self) -> _aws_cdk_aws_iam_ceddda9d.Role:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.get(self, "kinesisStreamRole"))
 
     @builtins.property
     @jsii.member(jsii_name="s3BucketInterface")
-    def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
-        return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
+    def s3_bucket_interface(self) -> _aws_cdk_aws_s3_ceddda9d.IBucket:
+        return typing.cast(_aws_cdk_aws_s3_ceddda9d.IBucket, jsii.get(self, "s3BucketInterface"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]]:
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
     @builtins.property
     @jsii.member(jsii_name="s3Bucket")
-    def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
+    def s3_bucket(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "s3Bucket"))
 
     @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
-    def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
+    def s3_logging_bucket(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "s3LoggingBucket"))
 
 
 @jsii.data_type(
@@ -287,15 +273,15 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
     def __init__(
         self,
         *,
-        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+        existing_logging_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+        existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        kinesis_stream_props: typing.Optional[typing.Union[_aws_cdk_aws_kinesis_ceddda9d.StreamProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''The properties for the KinesisStreamsToKinesisFirehoseToS3 class.
@@ -312,29 +298,15 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
         '''
         if isinstance(bucket_props, dict):
-            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+            bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**bucket_props)
         if isinstance(kinesis_stream_props, dict):
-            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
+            kinesis_stream_props = _aws_cdk_aws_kinesis_ceddda9d.StreamProps(**kinesis_stream_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+            logging_bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = _aws_cdk_aws_logs_ceddda9d.LogGroupProps(**log_group_props)
         if __debug__:
-            def stub(
-                *,
-                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_logging_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_firehose_props: typing.Any = None,
-                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                log_s3_access_logs: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c3baa5e8d7d7d4e3674dcf64793cf7bbb2d9d24681d094d9b571823df7743f24)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
@@ -345,7 +317,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
             check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
             check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
             check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
         if create_cloud_watch_alarms is not None:
@@ -368,13 +340,13 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
             self._values["log_s3_access_logs"] = log_s3_access_logs
 
     @builtins.property
-    def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    def bucket_props(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the S3 Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
@@ -386,7 +358,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+    def existing_bucket_obj(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket]:
         '''Optional existing instance of S3 Bucket, providing both this and bucketProps will cause an error.
 
         Providing both this and bucketProps will cause an error.
@@ -394,25 +366,29 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :default: - None
         '''
         result = self._values.get("existing_bucket_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket], result)
 
     @builtins.property
-    def existing_logging_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+    def existing_logging_bucket_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket]:
         '''Optional existing instance of logging S3 Bucket for the S3 Bucket created by the pattern.
 
         :default: - None
         '''
         result = self._values.get("existing_logging_bucket_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket], result)
 
     @builtins.property
-    def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
+    def existing_stream_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream]:
         '''Optional existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_stream_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream], result)
 
     @builtins.property
     def kinesis_firehose_props(self) -> typing.Any:
@@ -424,31 +400,37 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         return typing.cast(typing.Any, result)
 
     @builtins.property
-    def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
+    def kinesis_stream_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.StreamProps]:
         '''Optional user-provided props to override the default props for the Kinesis stream.
 
         :default: - Default props are used.
         '''
         result = self._values.get("kinesis_stream_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.StreamProps], result)
 
     @builtins.property
-    def logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    def logging_bucket_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the S3 Logging Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("logging_bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
-    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+    def log_group_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps]:
         '''Optional user provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
         '''
         result = self._values.get("log_group_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps], result)
 
     @builtins.property
     def log_s3_access_logs(self) -> typing.Optional[builtins.bool]:
@@ -479,3 +461,37 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8841925e06edd471b185af1ee7071d8da371a758c42ca2bf6eb79c9815681857(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    existing_logging_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
+    kinesis_firehose_props: typing.Any = None,
+    kinesis_stream_props: typing.Optional[typing.Union[_aws_cdk_aws_kinesis_ceddda9d.StreamProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_s3_access_logs: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c3baa5e8d7d7d4e3674dcf64793cf7bbb2d9d24681d094d9b571823df7743f24(
+    *,
+    bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    existing_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    existing_logging_bucket_obj: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
+    kinesis_firehose_props: typing.Any = None,
+    kinesis_stream_props: typing.Optional[typing.Union[_aws_cdk_aws_kinesis_ceddda9d.StreamProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_s3_access_logs: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
